This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  27e9e847d18de8df5ddafa72d6db80e9b657fb45 (commit)
       via  dd58a786fc59a5248f9061c27db546ea0bb67aef (commit)
      from  c4b0c12aa0c4745f6995b52c55deb7527a52f43b (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=27e9e847d18de8df5ddafa72d6db80e9b657fb45
commit 27e9e847d18de8df5ddafa72d6db80e9b657fb45
Merge: c4b0c12 dd58a78
Author:     Stephen Kelly <steve...@gmail.com>
AuthorDate: Thu Jan 15 18:00:40 2015 -0500
Commit:     CMake Topic Stage <kwro...@kitware.com>
CommitDate: Thu Jan 15 18:00:40 2015 -0500

    Merge topic 'GNU-4.6-compile-features' into next
    
    dd58a786 Features: Adjust the RunCMake test to use more-common features.


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=dd58a786fc59a5248f9061c27db546ea0bb67aef
commit dd58a786fc59a5248f9061c27db546ea0bb67aef
Author:     Stephen Kelly <steve...@gmail.com>
AuthorDate: Thu Jan 15 23:53:23 2015 +0100
Commit:     Stephen Kelly <steve...@gmail.com>
CommitDate: Thu Jan 15 23:53:23 2015 +0100

    Features: Adjust the RunCMake test to use more-common features.

diff --git 
a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake 
b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
index 9d56bc0..d2c95ec 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycle.cmake
@@ -3,12 +3,12 @@ add_library(empty1 empty.cpp)
 
 add_library(empty2 INTERFACE)
 add_library(empty3 INTERFACE)
-target_compile_features(empty3 INTERFACE cxx_constexpr)
+target_compile_features(empty3 INTERFACE cxx_static_assert)
 
 target_link_libraries(empty1
   # When starting, $<COMPILE_FEATURES:cxx_final> is '0', so 'freeze' the
   # CXX_STANDARD at 98 during computation.
-  $<$<COMPILE_FEATURES:cxx_final>:empty2>
+  $<$<COMPILE_FEATURES:cxx_nullptr>:empty2>
   # This would add cxx_constexpr, but that would require CXX_STANDARD = 11,
   # which is not allowed after freeze.  Report an error.
   empty3
@@ -3,12 +3,12 @@ add_library(empty1 empty.cpp)
 
 target_link_libraries(empty1
-  # When starting, $<COMPILE_FEATURES:cxx_final> is '0', so 'freeze' the
+  # When starting, $<COMPILE_FEATURES:cxx_nullptr> is '0', so 'freeze' the
   # CXX_STANDARD at 98 during computation.
diff --git 
a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycleSolved.cmake 
b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycleSolved.cmake
index 0df548b..bbcf4e0 100644
--- a/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycleSolved.cmake
+++ b/Tests/RunCMake/CompileFeatures/LinkImplementationFeatureCycleSolved.cmake
@@ -3,12 +3,12 @@ add_library(empty1 empty.cpp)
 
 add_library(empty2 INTERFACE)
 add_library(empty3 INTERFACE)
-target_compile_features(empty3 INTERFACE cxx_constexpr)
+target_compile_features(empty3 INTERFACE cxx_static_assert)
 
 target_link_libraries(empty1
-  $<$<COMPILE_FEATURES:cxx_final>:empty2>
+  $<$<COMPILE_FEATURES:cxx_nullptr>:empty2>
   empty3
 )
 # This, or populating the COMPILE_FEATURES property with a feature in the
 # same standard as cxx_final, solves the cycle above.
 set_property(TARGET empty1 PROPERTY CXX_STANDARD 11)

-----------------------------------------------------------------------

Summary of changes:
 .../CompileFeatures/LinkImplementationFeatureCycle.cmake         |    6 +++---
@@ -3,12 +3,12 @@ add_library(empty1 empty.cpp)
 )
 # This, or populating the COMPILE_FEATURES property with a feature in the
-# same standard as cxx_final, solves the cycle above.
+# same standard as cxx_nullptr, solves the cycle above.
 set_property(TARGET empty1 PROPERTY CXX_STANDARD 11)

 .../CompileFeatures/LinkImplementationFeatureCycleSolved.cmake   |    6 +++---
 2 files changed, 6 insertions(+), 6 deletions(-)


hooks/post-receive
-- 
CMake
_______________________________________________
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits

Reply via email to